==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/CustomTLSProfileFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class CustomTLSProfileFluentImpl<A extends io.fabric8.openshift.api.model.CustomTLSProfileFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.CustomTLSProfileFluent<A>{
  public CustomTLSProfileFluentImpl() {
  }
  public CustomTLSProfileFluentImpl(io.fabric8.openshift.api.model.CustomTLSProfile instance) {
    this.withCiphers(instance.getCiphers()); 
    this.withMinTLSVersion(instance.getMinTLSVersion()); 
  }
  private java.util.List<java.lang.String> ciphers = new java.util.ArrayList<java.lang.String>();
  private java.lang.String minTLSVersion;
  public A addToCiphers(java.lang.Integer index,java.lang.String item) {
    if (this.ciphers == null) {this.ciphers = new java.util.ArrayList<java.lang.String>();}
    this.ciphers.add(index, item);
    return (A)this;
  }
  public A setToCiphers(java.lang.Integer index,java.lang.String item) {
    if (this.ciphers == null) {this.ciphers = new java.util.ArrayList<java.lang.String>();}
    this.ciphers.set(index, item); return (A)this;
  }
  public A addToCiphers(java.lang.String... items) {
    if (this.ciphers == null) {this.ciphers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.ciphers.add(item);} return (A)this;
  }
  public A addAllToCiphers(java.util.Collection<java.lang.String> items) {
    if (this.ciphers == null) {this.ciphers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.ciphers.add(item);} return (A)this;
  }
  public A removeFromCiphers(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.ciphers!= null){ this.ciphers.remove(item);}} return (A)this;
  }
  public A removeAllFromCiphers(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.ciphers!= null){ this.ciphers.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getCiphers() {
    return this.ciphers;
  }
  public java.lang.String getCipher(java.lang.Integer index) {
    return this.ciphers.get(index);
  }
  public java.lang.String getFirstCipher() {
    return this.ciphers.get(0);
  }
  public java.lang.String getLastCipher() {
    return this.ciphers.get(ciphers.size() - 1);
  }
  public java.lang.String getMatchingCipher(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: ciphers) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingCipher(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: ciphers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCiphers(java.util.List<java.lang.String> ciphers) {
    if (ciphers != null) {this.ciphers = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : ciphers){this.addToCiphers(item);}} else { this.ciphers = null;} return (A) this;
  }
  public A withCiphers(java.lang.String... ciphers) {
    if (this.ciphers != null) {this.ciphers.clear();}
    if (ciphers != null) {for (java.lang.String item :ciphers){ this.addToCiphers(item);}} return (A) this;
  }
  public java.lang.Boolean hasCiphers() {
    return ciphers != null && !ciphers.isEmpty();
  }
  public A addNewCipher(java.lang.String arg0) {
    return (A)addToCiphers(new String(arg0));
  }
  public java.lang.String getMinTLSVersion() {
    return this.minTLSVersion;
  }
  public A withMinTLSVersion(java.lang.String minTLSVersion) {
    this.minTLSVersion=minTLSVersion; return (A) this;
  }
  public java.lang.Boolean hasMinTLSVersion() {
    return this.minTLSVersion != null;
  }
  
  /**
   * Method is deprecated. use withMinTLSVersion instead.
   */
  @java.lang.Deprecated
  public A withNewMinTLSVersion(java.lang.String arg0) {
    return (A)withMinTLSVersion(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomTLSProfileFluentImpl that = (CustomTLSProfileFluentImpl) o;
    if (ciphers != null ? !ciphers.equals(that.ciphers) :that.ciphers != null) return false;
    if (minTLSVersion != null ? !minTLSVersion.equals(that.minTLSVersion) :that.minTLSVersion != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ciphers,  minTLSVersion,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/CustomTLSProfileFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class CustomTLSProfileFluentImpl<A extends io.fabric8.openshift.api.model.CustomTLSProfileFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.CustomTLSProfileFluent<A>{
  public CustomTLSProfileFluentImpl() {
  }
  public CustomTLSProfileFluentImpl(io.fabric8.openshift.api.model.CustomTLSProfile instance) {
    this.withCiphers(instance.getCiphers()); 
    this.withMinTLSVersion(instance.getMinTLSVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> ciphers = new java.util.ArrayList<java.lang.String>();
  private java.lang.String minTLSVersion;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToCiphers(java.lang.Integer index,java.lang.String item) {
    if (this.ciphers == null) {this.ciphers = new java.util.ArrayList<java.lang.String>();}
    this.ciphers.add(index, item);
    return (A)this;
  }
  public A setToCiphers(java.lang.Integer index,java.lang.String item) {
    if (this.ciphers == null) {this.ciphers = new java.util.ArrayList<java.lang.String>();}
    this.ciphers.set(index, item); return (A)this;
  }
  public A addToCiphers(java.lang.String... items) {
    if (this.ciphers == null) {this.ciphers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.ciphers.add(item);} return (A)this;
  }
  public A addAllToCiphers(java.util.Collection<java.lang.String> items) {
    if (this.ciphers == null) {this.ciphers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.ciphers.add(item);} return (A)this;
  }
  public A removeFromCiphers(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.ciphers!= null){ this.ciphers.remove(item);}} return (A)this;
  }
  public A removeAllFromCiphers(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.ciphers!= null){ this.ciphers.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getCiphers() {
    return this.ciphers;
  }
  public java.lang.String getCipher(java.lang.Integer index) {
    return this.ciphers.get(index);
  }
  public java.lang.String getFirstCipher() {
    return this.ciphers.get(0);
  }
  public java.lang.String getLastCipher() {
    return this.ciphers.get(ciphers.size() - 1);
  }
  public java.lang.String getMatchingCipher(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: ciphers) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingCipher(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: ciphers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withCiphers(java.util.List<java.lang.String> ciphers) {
    if (ciphers != null) {this.ciphers = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : ciphers){this.addToCiphers(item);}} else { this.ciphers = null;} return (A) this;
  }
  public A withCiphers(java.lang.String... ciphers) {
    if (this.ciphers != null) {this.ciphers.clear();}
    if (ciphers != null) {for (java.lang.String item :ciphers){ this.addToCiphers(item);}} return (A) this;
  }
  public java.lang.Boolean hasCiphers() {
    return ciphers != null && !ciphers.isEmpty();
  }
  public A addNewCipher(java.lang.String arg0) {
    return (A)addToCiphers(new String(arg0));
  }
  public java.lang.String getMinTLSVersion() {
    return this.minTLSVersion;
  }
  public A withMinTLSVersion(java.lang.String minTLSVersion) {
    this.minTLSVersion=minTLSVersion; return (A) this;
  }
  public java.lang.Boolean hasMinTLSVersion() {
    return this.minTLSVersion != null;
  }
  
  /**
   * Method is deprecated. use withMinTLSVersion instead.
   */
  @java.lang.Deprecated
  public A withNewMinTLSVersion(java.lang.String arg0) {
    return (A)withMinTLSVersion(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CustomTLSProfileFluentImpl that = (CustomTLSProfileFluentImpl) o;
    if (ciphers != null ? !ciphers.equals(that.ciphers) :that.ciphers != null) return false;
    if (minTLSVersion != null ? !minTLSVersion.equals(that.minTLSVersion) :that.minTLSVersion != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(ciphers,  minTLSVersion,  additionalProperties,  super.hashCode());
  }
  
}
